Skip to main content
summaryrefslogtreecommitdiffstats
path: root/debug
diff options
context:
space:
mode:
Diffstat (limited to 'debug')
-rw-r--r--debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/internal/core/DebugStringVariableSubstitutor.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/internal/core/DebugStringVariableSubstitutor.java b/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/internal/core/DebugStringVariableSubstitutor.java
index 269df80fa0b..86c1c70bcc9 100644
--- a/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/internal/core/DebugStringVariableSubstitutor.java
+++ b/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/internal/core/DebugStringVariableSubstitutor.java
@@ -95,11 +95,11 @@ public class DebugStringVariableSubstitutor implements IStringVariableManager {
* variables in the context of the given project.
*
* @param projectName the name of the project used to resolve project_name, project_loc and
* project_path variables. If {@code null}, the project is determined based on the current
* selection.
*/
public DebugStringVariableSubstitutor(String projectName) {
- this(projectName == null ? null : ResourcesPlugin.getWorkspace().getRoot().getProject(projectName));
+ this(projectName == null || projectName.isEmpty() ? null : ResourcesPlugin.getWorkspace().getRoot().getProject(projectName));
}
public IStringVariable[] getVariables() {
@@ -95,11 +95,11 @@ public class DebugStringVariableSubstitutor implements IStringVariableManager {
*
* @param projectName the name of the project used to resolve project_name, project_loc and
- * project_path variables. If {@code null}, the project is determined based on the current
+ * project_path variables. If {@code null} or empty, the project is determined based on the current
* selection.
*/

Back to the top